@@ -13,10 +13,7 @@
 #include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTest>
-namespace KRunner
-{
-extern int __changeCountBeforeSaving;
-}
+#include <memory>
 using namespace KRunner;
 class RunnerManagerHistoryTest : public QObject
 {
@@ -24,7 +21,6 @@ class RunnerManagerHistoryTest : public QObject
 public:
     RunnerManagerHistoryTest()
     {
-        __changeCountBeforeSaving = 1;
         QStandardPaths::setTestModeEnabled(true);
         stateConfigFile = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + "krunnerstaterc";
     }
@@ -59,7 +55,6 @@ private Q_SLOTS:
     void testRunnerHistory();
     void testRunnerHistory_data();
     void testHistorySuggestionsAndRemoving();
-    void testRelevanceForOftenLaunched();
 };
 
 void RunnerManagerHistoryTest::testRunnerHistory()
@@ -105,43 +100,6 @@ void RunnerManagerHistoryTest::testHistorySuggestionsAndRemoving()
     QCOMPARE(manager.getHistorySuggestion("t"), "test2");
 }
 
-void RunnerManagerHistoryTest::testRelevanceForOftenLaunched()
-{
-    {
-        KConfig cfg(stateConfigFile);
-        cfg.group("PlasmaRunnerManager").writeEntry("LaunchCounts", "5 foo");
-        cfg.sync();
-    }
-    std::unique_ptr<RunnerManager> manager(new RunnerManager());
-    manager->setAllowedRunners({QStringLiteral("fakerunnerplugin")});
-    manager->loadRunner(KPluginMetaData::findPluginById(QStringLiteral("krunnertest"), QStringLiteral("fakerunnerplugin")));
-
-    launchQuery(QStringLiteral("foo"), manager.get());
-
-    const auto matches = manager->matches();
-    QCOMPARE(matches.size(), 2);
-    QCOMPARE(matches.at(0).id(), QStringLiteral("foo"));
-    QCOMPARE(matches.at(1).id(), QStringLiteral("bar"));
-    QCOMPARE(matches.at(1).relevance(), 0.2);
-
-    QVERIFY(matches.at(0).relevance() > matches.at(1).relevance());
-    QVERIFY(matches.at(0).relevance() < 0.6); // 0.5 is the max we add as a bonus, 0.1 comes from the runner
-    {
-        KConfig cfg(stateConfigFile);
-        cfg.group("PlasmaRunnerManager").writeEntry("LaunchCounts", QStringList{"5 foo", "5 bar"});
-        cfg.sync();
-        KSharedConfig::openConfig(QStringLiteral("krunnerstaterc"), KConfig::NoGlobals, QStandardPaths::GenericDataLocation)->reparseConfiguration();
-    }
-    manager.reset(new RunnerManager());
-    manager->setAllowedRunners({QStringLiteral("fakerunnerplugin")});
-    manager->loadRunner(KPluginMetaData::findPluginById(QStringLiteral("krunnertest"), QStringLiteral("fakerunnerplugin")));
-
-    launchQuery(QStringLiteral("foo"), manager.get());
-    const auto newMatches = manager->matches();
-    QCOMPARE(newMatches.size(), 2);
-    QVERIFY(newMatches.at(0).relevance() < newMatches.at(1).relevance());
-}
-
 QTEST_MAIN(RunnerManagerHistoryTest)
 
 #include "runnermanagerhistorytest.moc"
